@@ -7,3 +7,6 @@ class TinyContent(models.Model):
 
     def __unicode__(self):
         return self.name
+
+    class Meta:
+        verbose_name = 'Content block'
